try_command

Function try_command 

pub fn try_command(ctx: &LibraryContext, command: &str) -> Result<CommandGuard>
Take the library’s per-command lock, so one command runs against the library at a time. Different commands do not contend with each other, only with themselves.