pub fn original_path(hash: &str) -> PathBuf
Cache path for a full-resolution HEIC-converted original. One per hash (not per face, the original photo is the same regardless of which face on it was clicked).